==> bitcoin-23.0.tar.gz: bitcoin-23.0/src/qt/locale/bitcoin_zu.ts <==
<TS version="2.1" language="zu">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ifayela elehlukaniswe ngo khefana.</translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Iphutha langaphakathi.</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Sekwenzeke iphutha ngaphakathi. %1kuzozama ukuqhubeka ngokuphepha. Leli iphutha ebelingalindelekanga elingabikwa njengoba kuchaziwe ngezansi.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1Ingakatholakali ngokuphepha okwamanje.</translation>
    </message>
    <message>
        <source>Internal</source>
        <translation type="unfinished">Okwangaphakathi</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Ongakukhetha...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Shintsha Umushwana wokungena...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Sayina &amp;umlayezo...</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Qinisekisa umlayezo...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Vala isikhwama semali.</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Yakha isikhwama semali.</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Ukuxhumana no ntanga.</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Chofa ukuveza ezinye izenzo.</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Khubaza umsebenzi we nethiwekhi</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Akukwazi ukwenza uhlu lwabasayini.</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Umusayini wa ngaphandle</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>(of %1 GB needed)</source>
        <translation type="unfinished">(ku %1 GB odingakalayo)</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">Untanga</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ifayela elehlukaniswe ngo khefana.</translation>
    </message>
    </context>
</TS>

==> bitcoin-25.0.tar.gz: bitcoin-25.0/src/qt/locale/bitcoin_zu.ts <==
<TS version="2.1" language="zu">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Okusha</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopisha</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">Amakheli ukuthola</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ifayela elehlukaniswe ngo khefana.</translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Iphutha langaphakathi.</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Sekwenzeke iphutha ngaphakathi. %1kuzozama ukuqhubeka ngokuphepha. Leli iphutha ebelingalindelekanga elingabikwa njengoba kuchaziwe ngezansi.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1Ingakatholakali ngokuphepha okwamanje.</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Ongakukhetha...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Shintsha Umushwana wokungena...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Sayina &amp;umlayezo...</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Qinisekisa umlayezo...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Vala isikhwama semali.</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Yakha isikhwama semali.</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Ukuxhumana no ntanga.</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Chofa ukuveza ezinye izenzo.</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Khubaza umsebenzi we nethiwekhi</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Akukwazi ukwenza uhlu lwabasayini.</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Umusayini wa ngaphandle</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">Untanga</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Sign failed</source>
        <translation type="unfinished">Uphawu lwehlulekile</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Ifayela elehlukaniswe ngo khefana.</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error: Missing checksum</source>
        <translation type="unfinished">Iphutha: iChecksum engekho</translation>
    </message>
    </context>
</TS>
